@@ -13,10 +13,10 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@renovosolutions/aws-cdk-managed-instance-role",
-    "0.0.12",
+    "@renovosolutions/cdk-library-managed-instance-role",
+    "0.0.25",
     __name__[0:-6],
-    "aws-cdk-managed-instance-role@0.0.12.jsii.tgz",
+    "cdk-library-managed-instance-role@0.0.25.jsii.tgz",
 )
 
 __all__ = [
